@@ -42,6 +42,7 @@ import java.nio.charset.CharacterCodingException;
 import java.nio.charset.CharsetDecoder;
 import java.nio.charset.CharsetEncoder;
 import java.nio.charset.CoderResult;
+import java.nio.charset.StandardCharsets;
 import java.util.EnumSet;
 import java.util.Set;
 
@@ -522,6 +523,7 @@ public abstract class AbstractIoBuffer extends IoBuffer {
     /**
      * {@inheritDoc}
      */
+    @Override
     public IoBuffer putUnsigned(byte value) {
         autoExpand(1);
         buf().put((byte) (value & 0xff));
@@ -531,6 +533,7 @@ public abstract class AbstractIoBuffer extends IoBuffer {
     /**
      * {@inheritDoc}
      */
+    @Override
     public IoBuffer putUnsigned(int index, byte value) {
         autoExpand(index, 1);
         buf().put(index, (byte) (value & 0xff));
@@ -540,6 +543,7 @@ public abstract class AbstractIoBuffer extends IoBuffer {
     /**
      * {@inheritDoc}
      */
+    @Override
     public IoBuffer putUnsigned(short value) {
         autoExpand(1);
         buf().put((byte) (value & 0x00ff));
@@ -549,6 +553,7 @@ public abstract class AbstractIoBuffer extends IoBuffer {
     /**
      * {@inheritDoc}
      */
+    @Override
     public IoBuffer putUnsigned(int index, short value) {
         autoExpand(index, 1);
         buf().put(index, (byte) (value & 0x00ff));
@@ -558,6 +563,7 @@ public abstract class AbstractIoBuffer extends IoBuffer {
     /**
      * {@inheritDoc}
      */
+    @Override
     public IoBuffer putUnsigned(int value) {
         autoExpand(1);
         buf().put((byte) (value & 0x000000ff));
@@ -567,6 +573,7 @@ public abstract class AbstractIoBuffer extends IoBuffer {
     /**
      * {@inheritDoc}
      */
+    @Override
     public IoBuffer putUnsigned(int index, int value) {
         autoExpand(index, 1);
         buf().put(index, (byte) (value & 0x000000ff));
@@ -576,6 +583,7 @@ public abstract class AbstractIoBuffer extends IoBuffer {
     /**
      * {@inheritDoc}
      */
+    @Override
     public IoBuffer putUnsigned(long value) {
         autoExpand(1);
         buf().put((byte) (value & 0x00000000000000ffL));
@@ -585,6 +593,7 @@ public abstract class AbstractIoBuffer extends IoBuffer {
     /**
      * {@inheritDoc}
      */
+    @Override
     public IoBuffer putUnsigned(int index, long value) {
         autoExpand(index, 1);
         buf().put(index, (byte) (value & 0x00000000000000ffL));
@@ -828,7 +837,7 @@ public abstract class AbstractIoBuffer extends IoBuffer {
     @Override
     public final IoBuffer putUnsignedInt(byte value) {
         autoExpand(4);
-        buf().putInt((value & 0x00ff));
+        buf().putInt(value & 0x00ff);
         return this;
     }
 
@@ -838,7 +847,7 @@ public abstract class AbstractIoBuffer extends IoBuffer {
     @Override
     public final IoBuffer putUnsignedInt(int index, byte value) {
         autoExpand(index, 4);
-        buf().putInt(index, (value & 0x00ff));
+        buf().putInt(index, value & 0x00ff);
         return this;
     }
 
@@ -848,7 +857,7 @@ public abstract class AbstractIoBuffer extends IoBuffer {
     @Override
     public final IoBuffer putUnsignedInt(short value) {
         autoExpand(4);
-        buf().putInt((value & 0x0000ffff));
+        buf().putInt(value & 0x0000ffff);
         return this;
     }
 
@@ -858,7 +867,7 @@ public abstract class AbstractIoBuffer extends IoBuffer {
     @Override
     public final IoBuffer putUnsignedInt(int index, short value) {
         autoExpand(index, 4);
-        buf().putInt(index, (value & 0x0000ffff));
+        buf().putInt(index, value & 0x0000ffff);
         return this;
     }
 
@@ -867,9 +876,7 @@ public abstract class AbstractIoBuffer extends IoBuffer {
      */
     @Override
     public final IoBuffer putUnsignedInt(int value) {
-        autoExpand(4);
-        buf().putInt(value);
-        return this;
+        return putInt(value);
     }
 
     /**
@@ -877,9 +884,7 @@ public abstract class AbstractIoBuffer extends IoBuffer {
      */
     @Override
     public final IoBuffer putUnsignedInt(int index, int value) {
-        autoExpand(index, 4);
-        buf().putInt(index, value);
-        return this;
+        return putInt(index, value);
     }
 
     /**
@@ -927,9 +932,7 @@ public abstract class AbstractIoBuffer extends IoBuffer {
      */
     @Override
     public final IoBuffer putUnsignedShort(short value) {
-        autoExpand(2);
-        buf().putShort(value);
-        return this;
+        return putShort(value);
     }
 
     /**
@@ -937,9 +940,7 @@ public abstract class AbstractIoBuffer extends IoBuffer {
      */
     @Override
     public final IoBuffer putUnsignedShort(int index, short value) {
-        autoExpand(index, 2);
-        buf().putShort(index, value);
-        return this;
+        return putShort(index, value);
     }
 
     /**
@@ -1289,6 +1290,7 @@ public abstract class AbstractIoBuffer extends IoBuffer {
     /**
      * {@inheritDoc}
      */
+    @Override
     public int compareTo(IoBuffer that) {
         int n = this.position() + Math.min(this.remaining(), that.remaining());
         for (int i = this.position(), j = that.position(); i < n; i++, j++) {
@@ -1438,9 +1440,6 @@ public abstract class AbstractIoBuffer extends IoBuffer {
         return b3 << 16 | b2 << 8 | b1;
     }
 
-    /**
-     * {@inheritDoc}
-     */
     private int getMediumInt(byte b1, byte b2, byte b3) {
         int ret = b1 << 16 & 0xff0000 | b2 << 8 & 0xff00 | b3 & 0xff;
         // Check to see if the medium int is negative (high bit in b1 set)
@@ -1599,7 +1598,10 @@ public abstract class AbstractIoBuffer extends IoBuffer {
             return "";
         }
 
-        boolean utf16 = decoder.charset().name().startsWith("UTF-16");
+        boolean utf16 = 
+                decoder.charset().equals(StandardCharsets.UTF_16) ||
+                decoder.charset().equals(StandardCharsets.UTF_16BE) ||
+                decoder.charset().equals(StandardCharsets.UTF_16LE);
 
         int oldPos = position();
         int oldLimit = limit();
@@ -1707,7 +1709,9 @@ public abstract class AbstractIoBuffer extends IoBuffer {
             return "";
         }
 
-        boolean utf16 = decoder.charset().name().startsWith("UTF-16");
+        boolean utf16 = decoder.charset().equals(StandardCharsets.UTF_16) ||
+                decoder.charset().equals(StandardCharsets.UTF_16BE) ||
+                decoder.charset().equals(StandardCharsets.UTF_16LE);
 
         if (utf16 && (fieldSize & 1) != 0) {
             throw new IllegalArgumentException("fieldSize is not even.");
@@ -1855,7 +1859,10 @@ public abstract class AbstractIoBuffer extends IoBuffer {
 
         autoExpand(fieldSize);
 
-        boolean utf16 = encoder.charset().name().startsWith("UTF-16");
+        boolean utf16 = encoder.charset().equals(StandardCharsets.UTF_16) ||
+                encoder.charset().equals(StandardCharsets.UTF_16BE) ||
+                encoder.charset().equals(StandardCharsets.UTF_16LE);
+
 
         if (utf16 && (fieldSize & 1) != 0) {
             throw new IllegalArgumentException("fieldSize is not even.");
@@ -1954,7 +1961,10 @@ public abstract class AbstractIoBuffer extends IoBuffer {
             return "";
         }
 
-        boolean utf16 = decoder.charset().name().startsWith("UTF-16");
+        boolean utf16 = decoder.charset().equals(StandardCharsets.UTF_16) ||
+                decoder.charset().equals(StandardCharsets.UTF_16BE) ||
+                decoder.charset().equals(StandardCharsets.UTF_16LE);
+
 
         if (utf16 && (fieldSize & 1) != 0) {
             throw new BufferDataException("fieldSize is not even for a UTF-16 string.");
@@ -2168,10 +2178,8 @@ public abstract class AbstractIoBuffer extends IoBuffer {
 
         int oldLimit = limit();
         limit(position() + length);
-        ObjectInputStream in = null;
         
-        try {
-            in = new ObjectInputStream(asInputStream()) {
+        try (ObjectInputStream in = new ObjectInputStream(asInputStream()) {
                 @Override
                 protected ObjectStreamClass readClassDescriptor() throws IOException, ClassNotFoundException {
                     int type = read();
@@ -2205,19 +2213,11 @@ public abstract class AbstractIoBuffer extends IoBuffer {
                         return clazz;
                     }
                 }
-            };
+            }) {
             return in.readObject();
         } catch (IOException e) {
             throw new BufferDataException(e);
         } finally {
-            try {
-                if (in != null) {
-                    in.close();
-                }
-            } catch (IOException ioe) {
-                // Nothing to do
-            }
-            
             limit(oldLimit);
         }
     }
@@ -2229,10 +2229,8 @@ public abstract class AbstractIoBuffer extends IoBuffer {
     public IoBuffer putObject(Object o) {
         int oldPos = position();
         skip(4); // Make a room for the length field.
-        ObjectOutputStream out = null;
         
-        try {
-            out = new ObjectOutputStream(asOutputStream()) {
+        try (ObjectOutputStream out = new ObjectOutputStream(asOutputStream()) {
                 @Override
                 protected void writeClassDescriptor(ObjectStreamClass desc) throws IOException {
                     Class<?> clazz = desc.forClass();
@@ -2246,19 +2244,11 @@ public abstract class AbstractIoBuffer extends IoBuffer {
                         writeUTF(desc.getName());                            
                     }
                 }
-            };
+            }) {
             out.writeObject(o);
             out.flush();
         } catch (IOException e) {
             throw new BufferDataException(e);
-        } finally {
-            try {
-                if (out != null) {
-                    out.close();
-                }
-            } catch (IOException ioe) {
-                // Nothing to do
-            }
         }
 
         // Fill the length field
@@ -2496,6 +2486,7 @@ public abstract class AbstractIoBuffer extends IoBuffer {
     /**
      * {@inheritDoc}
      */
+    @Override
     public <E extends Enum<E>> E getEnumInt(int index, Class<E> enumClass) {
         return toEnum(enumClass, getInt(index));
     }
@@ -2577,7 +2568,7 @@ public abstract class AbstractIoBuffer extends IoBuffer {
      * {@inheritDoc}
      */
     @Override
-    public <E extends Enum<E>> EnumSet<E> getEnumSet(Class<E> enumClass) {
+    public <E extends Enum<E>> Set<E> getEnumSet(Class<E> enumClass) {
         return toEnumSet(enumClass, get() & BYTE_MASK);
     }
 
@@ -2585,7 +2576,7 @@ public abstract class AbstractIoBuffer extends IoBuffer {
      * {@inheritDoc}
      */
     @Override
-    public <E extends Enum<E>> EnumSet<E> getEnumSet(int index, Class<E> enumClass) {
+    public <E extends Enum<E>> Set<E> getEnumSet(int index, Class<E> enumClass) {
         return toEnumSet(enumClass, get(index) & BYTE_MASK);
     }
 
@@ -2593,7 +2584,7 @@ public abstract class AbstractIoBuffer extends IoBuffer {
      * {@inheritDoc}
      */
     @Override
-    public <E extends Enum<E>> EnumSet<E> getEnumSetShort(Class<E> enumClass) {
+    public <E extends Enum<E>> Set<E> getEnumSetShort(Class<E> enumClass) {
         return toEnumSet(enumClass, getShort() & SHORT_MASK);
     }
 
@@ -2601,7 +2592,7 @@ public abstract class AbstractIoBuffer extends IoBuffer {
      * {@inheritDoc}
      */
     @Override
-    public <E extends Enum<E>> EnumSet<E> getEnumSetShort(int index, Class<E> enumClass) {
+    public <E extends Enum<E>> Set<E> getEnumSetShort(int index, Class<E> enumClass) {
         return toEnumSet(enumClass, getShort(index) & SHORT_MASK);
     }
 
@@ -2609,7 +2600,7 @@ public abstract class AbstractIoBuffer extends IoBuffer {
      * {@inheritDoc}
      */
     @Override
-    public <E extends Enum<E>> EnumSet<E> getEnumSetInt(Class<E> enumClass) {
+    public <E extends Enum<E>> Set<E> getEnumSetInt(Class<E> enumClass) {
         return toEnumSet(enumClass, getInt() & INT_MASK);
     }
 
@@ -2617,7 +2608,7 @@ public abstract class AbstractIoBuffer extends IoBuffer {
      * {@inheritDoc}
      */
     @Override
-    public <E extends Enum<E>> EnumSet<E> getEnumSetInt(int index, Class<E> enumClass) {
+    public <E extends Enum<E>> Set<E> getEnumSetInt(int index, Class<E> enumClass) {
         return toEnumSet(enumClass, getInt(index) & INT_MASK);
     }
 
@@ -2625,7 +2616,7 @@ public abstract class AbstractIoBuffer extends IoBuffer {
      * {@inheritDoc}
      */
     @Override
-    public <E extends Enum<E>> EnumSet<E> getEnumSetLong(Class<E> enumClass) {
+    public <E extends Enum<E>> Set<E> getEnumSetLong(Class<E> enumClass) {
         return toEnumSet(enumClass, getLong());
     }
 
@@ -2633,7 +2624,7 @@ public abstract class AbstractIoBuffer extends IoBuffer {
      * {@inheritDoc}
      */
     @Override
-    public <E extends Enum<E>> EnumSet<E> getEnumSetLong(int index, Class<E> enumClass) {
+    public <E extends Enum<E>> Set<E> getEnumSetLong(int index, Class<E> enumClass) {
         return toEnumSet(enumClass, getLong(index));
     }
 
