@@ -30,7 +30,6 @@ import java.nio.DoubleBuffer;
 import java.nio.FloatBuffer;
 import java.nio.IntBuffer;
 import java.nio.LongBuffer;
-import java.nio.ReadOnlyBufferException;
 import java.nio.ShortBuffer;
 import java.nio.charset.CharacterCodingException;
 import java.nio.charset.CharsetDecoder;
@@ -152,6 +151,14 @@ public abstract class IoBuffer implements Comparable<IoBuffer> {
     /** A flag indicating which type of buffer we are using : heap or direct */
     private static boolean useDirectBuffer = false;
 
+    /**
+     * Creates a new instance. This is an empty constructor. It's protected, 
+     * to forbid its usage by the users.
+     */
+    protected IoBuffer() {
+        // Do nothing
+    }
+
     /**
      * @return the allocator used by existing and new buffers
      */
@@ -283,14 +290,6 @@ public abstract class IoBuffer implements Comparable<IoBuffer> {
         return newCapacity < 0 ? Integer.MAX_VALUE : newCapacity;
     }
 
-    /**
-     * Creates a new instance. This is an empty constructor. It's protected, 
-     * to forbid its usage by the users.
-     */
-    protected IoBuffer() {
-        // Do nothing
-    }
-
     /**
      * Declares this buffer and all its derived buffers are not used anymore so
      * that it can be reused by some {@link IoBufferAllocator} implementations.
@@ -1088,9 +1087,6 @@ public abstract class IoBuffer implements Comparable<IoBuffer> {
      * @param value The medium int value to be written
      * 
      * @return the modified IoBuffer
-     * 
-     * @throws BufferOverflowException If there are fewer than three bytes remaining in this buffer
-     * @throws ReadOnlyBufferException If this buffer is read-only
      */
     public abstract IoBuffer putMediumInt(int value);
 
@@ -1110,8 +1106,6 @@ public abstract class IoBuffer implements Comparable<IoBuffer> {
      * @throws IndexOutOfBoundsException
      *             If <tt>index</tt> is negative or not smaller than the
      *             buffer's limit, minus three
-     * 
-     * @throws ReadOnlyBufferException If this buffer is read-only
      */
     public abstract IoBuffer putMediumInt(int index, int value);
 
@@ -1326,9 +1320,6 @@ public abstract class IoBuffer implements Comparable<IoBuffer> {
      * 
      * @param index the position in the buffer to write the value
      * @param value the int to write
-     * 
-     * @param index The position where to put the unsigned short
-     * @param value The unsigned short to put in the IoBuffer
      * @return the modified IoBuffer
      */
     public abstract IoBuffer putUnsignedShort(int index, int value);
@@ -1372,7 +1363,6 @@ public abstract class IoBuffer implements Comparable<IoBuffer> {
      * @param index The position where to put the int
      * @param value The int to put in the IoBuffer
      * @return the modified IoBuffer
-     * @return the modified IoBuffer
      */
     public abstract IoBuffer putInt(int index, int value);
 
@@ -1412,7 +1402,6 @@ public abstract class IoBuffer implements Comparable<IoBuffer> {
      * @param index The position where to put the long
      * @param value The long to put in the IoBuffer
      * @return the modified IoBuffer
-     * @return the modified IoBuffer
      */
     public abstract IoBuffer putLong(int index, long value);
 
@@ -1937,7 +1926,7 @@ public abstract class IoBuffer implements Comparable<IoBuffer> {
      * @param enumClass the enum class used to create the EnumSet
      * @return the EnumSet representation of the bit vector
      */
-    public abstract <E extends Enum<E>> EnumSet<E> getEnumSet(Class<E> enumClass);
+    public abstract <E extends Enum<E>> Set<E> getEnumSet(Class<E> enumClass);
 
     /**
      * Reads a byte sized bit vector and converts it to an {@link EnumSet}.
@@ -1948,7 +1937,7 @@ public abstract class IoBuffer implements Comparable<IoBuffer> {
      * @param enumClass the enum class used to create the EnumSet
      * @return the EnumSet representation of the bit vector
      */
-    public abstract <E extends Enum<E>> EnumSet<E> getEnumSet(int index, Class<E> enumClass);
+    public abstract <E extends Enum<E>> Set<E> getEnumSet(int index, Class<E> enumClass);
 
     /**
      * Reads a short sized bit vector and converts it to an {@link EnumSet}.
@@ -1958,7 +1947,7 @@ public abstract class IoBuffer implements Comparable<IoBuffer> {
      * @param enumClass the enum class used to create the EnumSet
      * @return the EnumSet representation of the bit vector
      */
-    public abstract <E extends Enum<E>> EnumSet<E> getEnumSetShort(Class<E> enumClass);
+    public abstract <E extends Enum<E>> Set<E> getEnumSetShort(Class<E> enumClass);
 
     /**
      * Reads a short sized bit vector and converts it to an {@link EnumSet}.
@@ -1969,7 +1958,7 @@ public abstract class IoBuffer implements Comparable<IoBuffer> {
      * @param enumClass the enum class used to create the EnumSet
      * @return the EnumSet representation of the bit vector
      */
-    public abstract <E extends Enum<E>> EnumSet<E> getEnumSetShort(int index, Class<E> enumClass);
+    public abstract <E extends Enum<E>> Set<E> getEnumSetShort(int index, Class<E> enumClass);
 
     /**
      * Reads an int sized bit vector and converts it to an {@link EnumSet}.
@@ -1979,7 +1968,7 @@ public abstract class IoBuffer implements Comparable<IoBuffer> {
      * @param enumClass the enum class used to create the EnumSet
      * @return the EnumSet representation of the bit vector
      */
-    public abstract <E extends Enum<E>> EnumSet<E> getEnumSetInt(Class<E> enumClass);
+    public abstract <E extends Enum<E>> Set<E> getEnumSetInt(Class<E> enumClass);
 
     /**
      * Reads an int sized bit vector and converts it to an {@link EnumSet}.
@@ -1990,7 +1979,7 @@ public abstract class IoBuffer implements Comparable<IoBuffer> {
      * @param enumClass the enum class used to create the EnumSet
      * @return the EnumSet representation of the bit vector
      */
-    public abstract <E extends Enum<E>> EnumSet<E> getEnumSetInt(int index, Class<E> enumClass);
+    public abstract <E extends Enum<E>> Set<E> getEnumSetInt(int index, Class<E> enumClass);
 
     /**
      * Reads a long sized bit vector and converts it to an {@link EnumSet}.
@@ -2000,7 +1989,7 @@ public abstract class IoBuffer implements Comparable<IoBuffer> {
      * @param enumClass the enum class used to create the EnumSet
      * @return the EnumSet representation of the bit vector
      */
-    public abstract <E extends Enum<E>> EnumSet<E> getEnumSetLong(Class<E> enumClass);
+    public abstract <E extends Enum<E>> Set<E> getEnumSetLong(Class<E> enumClass);
 
     /**
      * Reads a long sized bit vector and converts it to an {@link EnumSet}.
@@ -2011,7 +2000,7 @@ public abstract class IoBuffer implements Comparable<IoBuffer> {
      * @param enumClass the enum class used to create the EnumSet
      * @return the EnumSet representation of the bit vector
      */
-    public abstract <E extends Enum<E>> EnumSet<E> getEnumSetLong(int index, Class<E> enumClass);
+    public abstract <E extends Enum<E>> Set<E> getEnumSetLong(int index, Class<E> enumClass);
 
     /**
      * Writes the specified {@link Set} to the buffer as a byte sized bit
