@@ -35,6 +35,7 @@ import org.apache.mina.core.session.IdleStatus;
 import org.apache.mina.core.session.IoSession;
 import org.apache.mina.core.write.WriteRequest;
 import org.apache.mina.core.write.WriteRequestQueue;
+import org.apache.mina.filter.FilterEvent;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -558,6 +559,14 @@ public class DefaultIoFilterChain implements IoFilterChain {
         callNextSessionOpened(head, session);
     }
 
+    /**
+     * {@inheritDoc}
+     */
+    @Override
+    public void fireEvent(FilterEvent event) {
+        callNextFilterEvent(head, session, event);
+    }
+
     private void callNextSessionOpened(Entry entry, IoSession session) {
         try {
             IoFilter filter = entry.getFilter();
@@ -733,7 +742,7 @@ public class DefaultIoFilterChain implements IoFilterChain {
      * {@inheritDoc}
      */
     @Override
-public void fireFilterWrite(WriteRequest writeRequest) {
+    public void fireFilterWrite(WriteRequest writeRequest) {
         callPreviousFilterWrite(tail, session, writeRequest);
     }
 
@@ -773,6 +782,19 @@ public void fireFilterWrite(WriteRequest writeRequest) {
         }
     }
 
+    private void callNextFilterEvent(Entry entry, IoSession session, FilterEvent event) {
+        try {
+            IoFilter filter = entry.getFilter();
+            NextFilter nextFilter = entry.getNextFilter();
+            filter.event(nextFilter, session, event);
+        } catch (Exception e) {
+            fireExceptionCaught(e);
+        } catch (Error e) {
+            fireExceptionCaught(e);
+            throw e;
+        }
+    }
+
     /**
      * {@inheritDoc}
      */
@@ -866,7 +888,7 @@ public void fireFilterWrite(WriteRequest writeRequest) {
     private class HeadFilter extends IoFilterAdapter {
         @SuppressWarnings("unchecked")
         @Override
-      public void filterWrite(NextFilter nextFilter, IoSession session, WriteRequest writeRequest) throws Exception {
+        public void filterWrite(NextFilter nextFilter, IoSession session, WriteRequest writeRequest) throws Exception {
             AbstractIoSession s = (AbstractIoSession) session;
 
             // Maintain counters.
@@ -875,7 +897,6 @@ public void fireFilterWrite(WriteRequest writeRequest) {
                 // I/O processor implementation will call buffer.reset()
                 // it after the write operation is finished, because
                 // the buffer will be specified with messageSent event.
-                buffer.mark();
                 int remaining = buffer.remaining();
 
                 if (remaining > 0) {
@@ -883,9 +904,7 @@ public void fireFilterWrite(WriteRequest writeRequest) {
                 }
             }
 
-            if (!writeRequest.isEncoded()) {
-                s.increaseScheduledWriteMessages();
-            }
+            s.increaseScheduledWriteMessages();
 
             WriteRequestQueue writeRequestQueue = s.getWriteRequestQueue();
 
@@ -902,7 +921,6 @@ public void fireFilterWrite(WriteRequest writeRequest) {
             }
         }
 
-
         @SuppressWarnings("unchecked")
         @Override
         public void filterClose(NextFilter nextFilter, IoSession session) throws Exception {
@@ -983,7 +1001,7 @@ public void fireFilterWrite(WriteRequest writeRequest) {
         public void messageReceived(NextFilter nextFilter, IoSession session, Object message) throws Exception {
             AbstractIoSession s = (AbstractIoSession) session;
 
-            if (!(message instanceof IoBuffer) || !((IoBuffer) message).hasRemaining()) {
+            if (message instanceof IoBuffer && !((IoBuffer) message).hasRemaining()) {
                 s.increaseReadMessages(System.currentTimeMillis());
             }
 
@@ -1004,25 +1022,21 @@ public void fireFilterWrite(WriteRequest writeRequest) {
 
         @Override
         public void messageSent(NextFilter nextFilter, IoSession session, WriteRequest writeRequest) throws Exception {
-            ((AbstractIoSession) session).increaseWrittenMessages(writeRequest, System.currentTimeMillis());
+            long now = System.currentTimeMillis();
+            ((AbstractIoSession) session).increaseWrittenMessages(writeRequest, now);
 
             // Update the statistics
             if (session.getService() instanceof AbstractIoService) {
-                ((AbstractIoService) session.getService()).getStatistics().updateThroughput(System.currentTimeMillis());
+                ((AbstractIoService) session.getService()).getStatistics().updateThroughput(now);
             }
 
             // Propagate the message
-            session.getHandler().messageSent(session, writeRequest.getMessage());
+            session.getHandler().messageSent(session, writeRequest.getOriginalMessage());
         }
-
+        
         @Override
-        public void filterWrite(NextFilter nextFilter, IoSession session, WriteRequest writeRequest) throws Exception {
-            nextFilter.filterWrite(session, writeRequest);
-        }
-
-        @Override
-        public void filterClose(NextFilter nextFilter, IoSession session) throws Exception {
-            nextFilter.filterClose(session);
+        public void event(NextFilter nextFilter, IoSession session, FilterEvent event) throws Exception {
+            session.getHandler().event(session, event);
         }
     }
 
@@ -1141,6 +1155,15 @@ public void fireFilterWrite(WriteRequest writeRequest) {
                     callPreviousFilterClose(nextEntry, session);
                 }
 
+                /**
+                 * {@inheritDoc}
+                 */
+                @Override
+                public void event(IoSession session, FilterEvent event) {
+                    Entry nextEntry = EntryImpl.this.nextEntry;
+                    callNextFilterEvent(nextEntry, session, event);
+                }
+
                 /**
                  * {@inheritDoc}
                  */
