@@ -30,6 +30,7 @@ import org.apache.mina.core.session.IdleStatus;
 import org.apache.mina.core.session.IoSession;
 import org.apache.mina.core.session.IoSessionConfig;
 import org.apache.mina.core.session.IoSessionInitializer;
+import org.apache.mina.filter.FilterEvent;
 
 /**
  * A base implementation of {@link IoConnector}.
@@ -313,6 +314,14 @@ public abstract class AbstractIoConnector extends AbstractIoService implements I
                     public void inputClosed(IoSession session) throws Exception {
                         // Empty handler
                     }
+
+                    /**
+                     * {@inheritDoc}
+                     */
+                    @Override
+                    public void event(IoSession session, FilterEvent event) throws Exception {
+                        // Empty handler
+                    }
                 });
             } else {
                 throw new IllegalStateException("handler is not set.");
