@@ -192,13 +192,13 @@ public class OrderedThreadPoolExecutor extends ThreadPoolExecutor {
             throw new IllegalArgumentException("corePoolSize: " + corePoolSize);
         }
 
-        if ((maximumPoolSize == 0) || (maximumPoolSize < corePoolSize)) {
+        if ((maximumPoolSize <= 0) || (maximumPoolSize < corePoolSize)) {
             throw new IllegalArgumentException("maximumPoolSize: " + maximumPoolSize);
         }
 
         // Now, we can setup the pool sizes
-        super.setCorePoolSize(corePoolSize);
         super.setMaximumPoolSize(maximumPoolSize);
+        super.setCorePoolSize(corePoolSize);
 
         // The queueHandler might be null.
         if (eventQueueHandler == null) {
@@ -411,6 +411,7 @@ public class OrderedThreadPoolExecutor extends ThreadPoolExecutor {
         sb.append("Adding event ").append(event.getType()).append(" to session ").append(event.getSession().getId());
         boolean first = true;
         sb.append("\nQueue : [");
+        
         for (Runnable elem : queue) {
             if (first) {
                 first = false;
@@ -420,8 +421,12 @@ public class OrderedThreadPoolExecutor extends ThreadPoolExecutor {
 
             sb.append(((IoEvent) elem).getType()).append(", ");
         }
+        
         sb.append("]\n");
-        LOGGER.debug(sb.toString());
+        
+        if (LOGGER.isDebugEnabled()) {
+            LOGGER.debug(sb.toString());
+        }
     }
 
     /**
