@@ -41,8 +41,8 @@ import org.apache.mina.core.service.IoAcceptor;
 import org.apache.mina.core.service.IoHandler;
 import org.apache.mina.core.session.AttributeKey;
 import org.apache.mina.core.session.IoSession;
+import org.apache.mina.core.write.DefaultWriteRequest;
 import org.apache.mina.core.write.WriteRequest;
-import org.apache.mina.core.write.WriteRequestWrapper;
 import org.apache.mina.core.write.WriteToClosedSessionException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -111,7 +111,7 @@ public class SslFilter extends IoFilterAdapter {
     /**
      * A session attribute key that makes this filter to emit a
      * {@link IoHandler#messageReceived(IoSession, Object)} event with a
-     * special message ({@link #SESSION_SECURED} or {@link #SESSION_UNSECURED}).
+     * special message ({@link SslEvent#SECURED} or {@link SslEvent#UNSECURED}).
      * This is a marker attribute, which means that you can put whatever as its
      * value. ({@link Boolean#TRUE} is preferred.)  By default, this filter
      * doesn't emit any events related with SSL session flow control.
@@ -133,20 +133,6 @@ public class SslFilter extends IoFilterAdapter {
      */
     public static final AttributeKey PEER_ADDRESS = new AttributeKey(SslFilter.class, "peerAddress");
 
-    /**
-     * A special message object which is emitted with a {@link IoHandler#messageReceived(IoSession, Object)}
-     * event when the session is secured and its {@link #USE_NOTIFICATION}
-     * attribute is set.
-     */
-    public static final SslFilterMessage SESSION_SECURED = new SslFilterMessage("SESSION_SECURED");
-
-    /**
-     * A special message object which is emitted with a {@link IoHandler#messageReceived(IoSession, Object)}
-     * event when the session is not secure anymore and its {@link #USE_NOTIFICATION}
-     * attribute is set.
-     */
-    public static final SslFilterMessage SESSION_UNSECURED = new SslFilterMessage("SESSION_UNSECURED");
-
     /** An attribute containing the next filter */
     private static final AttributeKey NEXT_FILTER = new AttributeKey(SslFilter.class, "nextFilter");
 
@@ -237,9 +223,9 @@ public class SslFilter extends IoFilterAdapter {
                 } else {
                     started = false;
                 }
+                sslHandler.flushFilterWrite();
             }
-
-            sslHandler.flushScheduledEvents();
+            sslHandler.flushMessageReceived();
         } catch (SSLException se) {
             sslHandler.release();
             throw se;
@@ -336,9 +322,8 @@ public class SslFilter extends IoFilterAdapter {
         try {
             synchronized (sslHandler) {
                 future = initiateClosure(nextFilter, session);
+                sslHandler.flushFilterWrite();
             }
-
-            sslHandler.flushScheduledEvents();
         } catch (SSLException se) {
             sslHandler.release();
             throw se;
@@ -454,7 +439,9 @@ public class SslFilter extends IoFilterAdapter {
             throw new IllegalStateException(msg);
         }
 
-        LOGGER.debug("Adding the SSL Filter {} to the chain", name);
+        if (LOGGER.isDebugEnabled()) {
+            LOGGER.debug("Adding the SSL Filter {} to the chain", name);
+        }
 
         IoSession session = parent.getSession();
         session.setAttribute(NEXT_FILTER, nextFilter);
@@ -511,58 +498,58 @@ public class SslFilter extends IoFilterAdapter {
 
         SslHandler sslHandler = getSslSessionHandler(session);
 
-        synchronized (sslHandler) {
-            if (!isSslStarted(session) && sslHandler.isInboundDone()) {
-                // The SSL session must be established first before we
-                // can push data to the application. Store the incoming
-                // data into a queue for a later processing
-                sslHandler.scheduleMessageReceived(nextFilter, message);
-            } else {
-                IoBuffer buf = (IoBuffer) message;
+	synchronized (sslHandler) {
+	    if (!isSslStarted(session) && sslHandler.isInboundDone()) {
+		// The SSL session must be established first before we
+		// can push data to the application. Store the incoming
+		// data into a queue for a later processing
+		sslHandler.scheduleMessageReceived(nextFilter, message);
+	    } else {
+		IoBuffer buf = (IoBuffer) message;
 
-                try {
-                    if (sslHandler.isOutboundDone()) {
-                        sslHandler.destroy();
-                        throw new SSLException("Outbound done");
-                    }
-                    
-                    // forward read encrypted data to SSL handler
-                    sslHandler.messageReceived(nextFilter, buf.buf());
+		try {
+		    if (sslHandler.isOutboundDone()) {
+			sslHandler.destroy();
+			throw new SSLException("Outbound done");
+		    }
 
-                    // Handle data to be forwarded to application or written to net
-                    handleSslData(nextFilter, sslHandler);
+		    // forward read encrypted data to SSL handler
+		    sslHandler.messageReceived(nextFilter, buf.buf());
 
-                    if (sslHandler.isInboundDone()) {
-                        if (sslHandler.isOutboundDone()) {
-                            sslHandler.destroy();
-                        } else {
-                            initiateClosure(nextFilter, session);
-                        }
+		    // Handle data to be forwarded to application or written to net
+		    handleSslData(nextFilter, sslHandler);
 
-                        if (buf.hasRemaining()) {
-                            // Forward the data received after closure.
-                            sslHandler.scheduleMessageReceived(nextFilter, buf);
-                        }
-                    }
-                } catch (SSLException ssle) {
-                    if (!sslHandler.isHandshakeComplete()) {
-                        SSLException newSsle = new SSLHandshakeException("SSL handshake failed.");
-                        newSsle.initCause(ssle);
-                        ssle = newSsle;
-                        
-                        // Close the session immediately, the handshake has failed
-                        session.closeNow();
-                    } else {
-                        // Free the SSL Handler buffers
-                        sslHandler.release();
-                    }
+		    if (sslHandler.isInboundDone()) {
+			if (sslHandler.isOutboundDone()) {
+			    sslHandler.destroy();
+			} else {
+			    initiateClosure(nextFilter, session);
+			}
 
-                    throw ssle;
-                }
-            }
-        }
+			if (buf.hasRemaining()) {
+			    // Forward the data received after closure.
+			    sslHandler.scheduleMessageReceived(nextFilter, buf);
+			}
+		    }
+		} catch (SSLException ssle) {
+		    if (!sslHandler.isHandshakeComplete()) {
+			SSLException newSsle = new SSLHandshakeException("SSL handshake failed.");
+			newSsle.initCause(ssle);
+			ssle = newSsle;
 
-        sslHandler.flushScheduledEvents();
+			// Close the session immediately, the handshake has failed
+			session.closeNow();
+		    } else {
+			// Free the SSL Handler buffers
+			sslHandler.release();
+		    }
+
+		    throw ssle;
+		}
+	    }
+	}
+	
+	sslHandler.flushMessageReceived();
     }
 
     @Override
@@ -663,11 +650,11 @@ public class SslFilter extends IoFilterAdapter {
                         sslHandler.scheduleFilterWrite(nextFilter, writeRequest);
                     } else if (sslHandler.isHandshakeComplete()) {
                         // SSL encrypt
-                        buf.mark();
                         sslHandler.encrypt(buf.buf());
                         IoBuffer encryptedBuffer = sslHandler.fetchOutNetBuffer();
+                        writeRequest.setMessage( encryptedBuffer );
                         sslHandler.scheduleFilterWrite(nextFilter, new EncryptedWriteRequest(writeRequest,
-                                encryptedBuffer));
+                            encryptedBuffer));
                     } else {
                         if (session.isConnected()) {
                             // Handshake not complete yet.
@@ -677,10 +664,9 @@ public class SslFilter extends IoFilterAdapter {
                         needsFlush = false;
                     }
                 }
-            }
-
-            if (needsFlush) {
-                sslHandler.flushScheduledEvents();
+                if (needsFlush) {
+                    sslHandler.flushFilterWrite();
+                }
             }
         } catch (SSLException se) {
             sslHandler.release();
@@ -712,9 +698,8 @@ public class SslFilter extends IoFilterAdapter {
                         }
                     });
                 }
+                sslHandler.flushFilterWrite();
             }
-
-            sslHandler.flushScheduledEvents();
         } catch (SSLException se) {
             sslHandler.release();
             throw se;
@@ -749,15 +734,18 @@ public class SslFilter extends IoFilterAdapter {
     }
 
     private void initiateHandshake(NextFilter nextFilter, IoSession session) throws SSLException {
-        LOGGER.debug("{} : Starting the first handshake", getSessionInfo(session));
+        if (LOGGER.isDebugEnabled()) {
+            LOGGER.debug("{} : Starting the first handshake", getSessionInfo(session));
+        }
+        
         SslHandler sslHandler = getSslSessionHandler(session);
 
         try {
             synchronized (sslHandler) {
                 sslHandler.handshake(nextFilter);
+                sslHandler.flushFilterWrite();
             }
-
-            sslHandler.flushScheduledEvents();
+            sslHandler.flushMessageReceived();
         } catch (SSLException se) {
             sslHandler.release();
             throw se;
@@ -788,10 +776,8 @@ public class SslFilter extends IoFilterAdapter {
                 }
             }
 
-            if (session.containsAttribute(USE_NOTIFICATION)) {
-                sslHandler.scheduleMessageReceived(nextFilter, SESSION_UNSECURED);
-            }
-            
+            // Inform that the session is not any more secured
+            session.getFilterChain().fireEvent(SslEvent.UNSECURED);
         } catch (SSLException se) {
             sslHandler.release();
             throw se;
@@ -861,18 +847,52 @@ public class SslFilter extends IoFilterAdapter {
             return name;
         }
     }
-
-    private static class EncryptedWriteRequest extends WriteRequestWrapper {
+    
+    /**
+     * A private class used to store encrypted messages. This is necessary
+     * to be able to emit the messageSent event with the proper original
+     * message, but not for handshake messages, which will be swallowed.
+     *
+     */
+    /* package protected */ static class EncryptedWriteRequest extends DefaultWriteRequest {
+        // Thee encrypted messagee
         private final IoBuffer encryptedMessage;
+        
+        // The original message
+        private WriteRequest parentRequest;
 
+        /**
+         * Create a new instance of an EncryptedWriteRequest
+         * @param writeRequest The parent request
+         * @param encryptedMessage The encrypted message
+         */
         private EncryptedWriteRequest(WriteRequest writeRequest, IoBuffer encryptedMessage) {
-            super(writeRequest);
+            super(encryptedMessage);
+            parentRequest = writeRequest;
             this.encryptedMessage = encryptedMessage;
         }
 
+        /**
+         * @return teh encrypted message
+         */
         @Override
         public Object getMessage() {
             return encryptedMessage;
         }
+
+        /**
+         * @return The parent WriteRequest
+         */
+        public WriteRequest getParentRequest() {
+            return parentRequest;
+        }
+        
+        /**
+         * {@inheritDoc}
+         */
+        @Override
+        public WriteFuture getFuture() {
+            return parentRequest.getFuture();
+        }
     }
 }
