@@ -28,10 +28,12 @@ import java.util.concurrent.locks.ReentrantLock;
 
 import javax.net.ssl.SSLEngine;
 import javax.net.ssl.SSLEngineResult;
+import javax.net.ssl.SSLEngineResult.HandshakeStatus;
 import javax.net.ssl.SSLEngineResult.Status;
 import javax.net.ssl.SSLException;
 import javax.net.ssl.SSLHandshakeException;
 
+import org.apache.mina.core.RuntimeIoException;
 import org.apache.mina.core.buffer.IoBuffer;
 import org.apache.mina.core.filterchain.IoFilter.NextFilter;
 import org.apache.mina.core.filterchain.IoFilterEvent;
@@ -41,6 +43,8 @@ import org.apache.mina.core.session.IoEventType;
 import org.apache.mina.core.session.IoSession;
 import org.apache.mina.core.write.DefaultWriteRequest;
 import org.apache.mina.core.write.WriteRequest;
+import org.apache.mina.core.write.WriteRequestQueue;
+import org.apache.mina.filter.ssl.SslFilter.EncryptedWriteRequest;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -115,12 +119,6 @@ class SslHandler {
      * for data being produced during the handshake). */
     private boolean writingEncryptedData;
 
-    /** A lock to protect the SSL flush of events */
-    private ReentrantLock sslLock = new ReentrantLock();
-    
-    /** A counter of schedules events */
-    private final AtomicInteger scheduledEvents = new AtomicInteger(0);
-
     /**
      * Create a new SSL Handler, and initialize it.
      *
@@ -143,7 +141,9 @@ class SslHandler {
             return;
         }
 
-        LOGGER.debug("{} Initializing the SSL Handler", sslFilter.getSessionInfo(session));
+        if (LOGGER.isDebugEnabled()) {
+            LOGGER.debug("{} Initializing the SSL Handler", sslFilter.getSessionInfo(session));
+        }
 
         InetSocketAddress peer = (InetSocketAddress) session.getAttribute(SslFilter.PEER_ADDRESS);
 
@@ -209,7 +209,9 @@ class SslHandler {
         try {
             sslEngine.closeInbound();
         } catch (SSLException e) {
-            LOGGER.debug("Unexpected exception from SSLEngine.closeInbound().", e);
+            if (LOGGER.isDebugEnabled()) {
+                LOGGER.debug("Unexpected exception from SSLEngine.closeInbound().", e);
+            }
         }
 
         if (outNetBuffer != null) {
@@ -259,6 +261,13 @@ class SslHandler {
         return handshakeComplete;
     }
 
+    /**
+     * Check if handshake is on going.
+     */
+    /* no qualifier */boolean notHandshaking() {
+        return handshakeStatus == HandshakeStatus.FINISHED || handshakeStatus == HandshakeStatus.NOT_HANDSHAKING;
+    }
+
     /* no qualifier */boolean isInboundDone() {
         return sslEngine == null || sslEngine.isInboundDone();
     }
@@ -291,6 +300,18 @@ class SslHandler {
         filterWriteEventQueue.add(new IoFilterEvent(nextFilter, IoEventType.WRITE, session, writeRequest));
     }
 
+    /* no qualifier */void flushFilterWrite() {
+        // Fire events only when the lock is available for this handler.
+        IoFilterEvent event;
+    
+        // We need synchronization here inevitably because filterWrite can be
+        // called simultaneously and cause 'bad record MAC' integrity error.
+        while ((event = filterWriteEventQueue.poll()) != null) {
+            NextFilter nextFilter = event.getNextFilter();
+            nextFilter.filterWrite(session, (WriteRequest) event.getParameter());
+        }
+    }
+
     /**
      * Push the newly received data into a queue, waiting for the SSL session
      * to be fully established
@@ -301,32 +322,14 @@ class SslHandler {
     /* no qualifier */void scheduleMessageReceived(NextFilter nextFilter, Object message) {
         messageReceivedEventQueue.add(new IoFilterEvent(nextFilter, IoEventType.MESSAGE_RECEIVED, session, message));
     }
+    
+    /* no qualifier */void flushMessageReceived() {
+	IoFilterEvent event;
 
-    /* no qualifier */void flushScheduledEvents() {
-        scheduledEvents.incrementAndGet();
-
-        // Fire events only when the lock is available for this handler.
-        if (sslLock.tryLock()) {
-            IoFilterEvent event;
-            
-            try {
-                do {
-                    // We need synchronization here inevitably because filterWrite can be
-                    // called simultaneously and cause 'bad record MAC' integrity error.
-                    while ((event = filterWriteEventQueue.poll()) != null) {
-                        NextFilter nextFilter = event.getNextFilter();
-                        nextFilter.filterWrite(session, (WriteRequest) event.getParameter());
-                    }
-            
-                    while ((event = messageReceivedEventQueue.poll()) != null) {
-                        NextFilter nextFilter = event.getNextFilter();
-                        nextFilter.messageReceived(session, event.getParameter());
-                    }
-                } while (scheduledEvents.decrementAndGet() > 0);
-            } finally {
-                sslLock.unlock();
-            }
-        }
+	while ((event = messageReceivedEventQueue.poll()) != null) {
+	    NextFilter nextFilter = event.getNextFilter();
+	    nextFilter.messageReceived(session, event.getParameter());
+	}
     }
 
     /**
@@ -516,9 +519,36 @@ class SslHandler {
          * UNDERFLOW - Need to read more data from the socket. It's normal.
          * CLOSED - The other peer closed the socket. Also normal.
          */
-        if (status == SSLEngineResult.Status.BUFFER_OVERFLOW) {
-            throw new SSLException("SSLEngine error during decrypt: " + status + " inNetBuffer: " + inNetBuffer
+        switch (status) {
+            case BUFFER_OVERFLOW:
+                throw new SSLException("SSLEngine error during decrypt: " + status + " inNetBuffer: " + inNetBuffer
                     + "appBuffer: " + appBuffer);
+            case CLOSED:
+                Exception exception =new RuntimeIoException("SSL/TLS close_notify received");
+                
+                // Empty the Ssl queue
+                for (IoFilterEvent event:filterWriteEventQueue) {
+                    EncryptedWriteRequest writeRequest = (EncryptedWriteRequest)event.getParameter();
+                    WriteFuture writeFuture = writeRequest.getParentRequest().getFuture();
+                    writeFuture.setException(exception);
+                    writeFuture.notifyAll();
+                }
+                
+                // Empty the session queue
+                WriteRequestQueue queue = session.getWriteRequestQueue();
+                WriteRequest request = null;
+               
+    	    	while ((request = queue.poll(session)) != null) {
+    	    	    WriteFuture writeFuture = request.getFuture();
+    	    	    writeFuture.setException(exception);
+    	    	    writeFuture.notifyAll();
+        	}
+                    
+                // We *must* shutdown session
+                session.closeNow();
+                break;
+            default: 
+                break;
         }
     }
 
@@ -537,9 +567,10 @@ class SslHandler {
                 handshakeComplete = true;
 
                 // Send the SECURE message only if it's the first SSL handshake
-                if (firstSSLNegociation && session.containsAttribute(SslFilter.USE_NOTIFICATION)) {
-                    // SESSION_SECURED is fired only when it's the first handshake
-                    scheduleMessageReceived(nextFilter, SslFilter.SESSION_SECURED);
+                if (firstSSLNegociation) {
+                    firstSSLNegociation = false;
+                    
+                    nextFilter.event(session, SslEvent.SECURED);
                 }
 
                 if (LOGGER.isDebugEnabled()) {
@@ -582,8 +613,7 @@ class SslHandler {
                 }
 
                 // First make sure that the out buffer is completely empty.
-                // Since we
-                // cannot call wrap with data left on the buffer
+                // Since we cannot call wrap with data left on the buffer
                 if (outNetBuffer != null && outNetBuffer.hasRemaining()) {
                     return;
                 }
@@ -740,6 +770,7 @@ class SslHandler {
 
         SSLEngineResult res;
         Status status;
+        HandshakeStatus localHandshakeStatus;
 
         do {
             // Decode the incoming data
@@ -747,7 +778,7 @@ class SslHandler {
             status = res.getStatus();
 
             // We can be processing the Handshake
-            handshakeStatus = res.getHandshakeStatus();
+            localHandshakeStatus = res.getHandshakeStatus();
 
             if (status == SSLEngineResult.Status.BUFFER_OVERFLOW) {
                 // We have to grow the target buffer, it's too small.
@@ -764,8 +795,8 @@ class SslHandler {
                 continue;
             }
         } while (((status == SSLEngineResult.Status.OK) || (status == SSLEngineResult.Status.BUFFER_OVERFLOW))
-                && ((handshakeStatus == SSLEngineResult.HandshakeStatus.NOT_HANDSHAKING) || 
-                        (handshakeStatus == SSLEngineResult.HandshakeStatus.NEED_UNWRAP)));
+                && ((localHandshakeStatus == SSLEngineResult.HandshakeStatus.NOT_HANDSHAKING) || 
+                        (localHandshakeStatus == SSLEngineResult.HandshakeStatus.NEED_UNWRAP)));
 
         return res;
     }
