@@ -44,14 +44,14 @@ import org.apache.mina.core.session.SessionState;
  *
  * @author <a href="http://mina.apache.org">Apache MINA Project</a>
  */
-public final class NioProcessor extends AbstractPollingIoProcessor<NioSession> {
+public class NioProcessor extends AbstractPollingIoProcessor<NioSession> {
     /** The selector associated with this processor */
-    private Selector selector;
+    protected Selector selector;
     
     /** A lock used to protect concurent access to the selector */
-    private ReadWriteLock selectorLock = new ReentrantReadWriteLock();
+    protected ReadWriteLock selectorLock = new ReentrantReadWriteLock();
 
-    private SelectorProvider selectorProvider = null;
+    protected SelectorProvider selectorProvider = null;
 
     /**
      *
