@@ -23,6 +23,7 @@ import java.io.IOException;
 import java.net.InetSocketAddress;
 import java.net.ServerSocket;
 import java.net.SocketAddress;
+import java.net.StandardSocketOptions;
 import java.nio.channels.SelectionKey;
 import java.nio.channels.Selector;
 import java.nio.channels.ServerSocketChannel;
@@ -40,6 +41,7 @@ import org.apache.mina.core.service.SimpleIoProcessorPool;
 import org.apache.mina.core.service.TransportMetadata;
 import org.apache.mina.transport.socket.DefaultSocketSessionConfig;
 import org.apache.mina.transport.socket.SocketAcceptor;
+import org.apache.mina.transport.socket.SocketSessionConfig;
 
 /**
  * {@link IoAcceptor} for socket transport (TCP/IP).  This class
@@ -47,11 +49,11 @@ import org.apache.mina.transport.socket.SocketAcceptor;
  *
  * @author <a href="http://mina.apache.org">Apache MINA Project</a>
  */
-public final class NioSocketAcceptor extends AbstractPollingIoAcceptor<NioSession, ServerSocketChannel>
+public class NioSocketAcceptor extends AbstractPollingIoAcceptor<NioSession, ServerSocketChannel>
 implements SocketAcceptor {
 
-    private volatile Selector selector;
-    private volatile SelectorProvider selectorProvider = null;
+    protected volatile Selector selector;
+    protected volatile SelectorProvider selectorProvider = null;
 
     /**
      * Constructor for {@link NioSocketAcceptor} using default parameters (multiple thread model).
@@ -226,6 +228,8 @@ implements SocketAcceptor {
     protected ServerSocketChannel open(SocketAddress localAddress) throws Exception {
         // Creates the listening ServerSocket
 
+	SocketSessionConfig config = this.getSessionConfig();
+	
         ServerSocketChannel channel = null;
 
         if (selectorProvider != null) {
@@ -245,6 +249,16 @@ implements SocketAcceptor {
 
             // Set the reuseAddress flag accordingly with the setting
             socket.setReuseAddress(isReuseAddress());
+            
+            // Set the SND BUFF
+	    if (config.getSendBufferSize() != -1) {
+		channel.setOption(StandardSocketOptions.SO_SNDBUF, config.getSendBufferSize());
+	    }
+
+	    // Set the RCV BUFF
+	    if (config.getReceiveBufferSize() != -1) {
+		channel.setOption(StandardSocketOptions.SO_RCVBUF, config.getReceiveBufferSize());
+	    }
 
             // and bind.
             try {
@@ -252,10 +266,8 @@ implements SocketAcceptor {
             } catch (IOException ioe) {
                 // Add some info regarding the address we try to bind to the
                 // message
-                String newMessage = "Error while binding on " + localAddress + "\n" + "original message : "
-                        + ioe.getMessage();
-                Exception e = new IOException(newMessage);
-                e.initCause(ioe.getCause());
+                String newMessage = "Error while binding on " + localAddress;
+                Exception e = new IOException(newMessage, ioe);
 
                 // And close the channel
                 channel.close();
