@@ -19,8 +19,7 @@
  */
 package org.apache.mina.filter.ssl;
 
-import static org.junit.Assert.assertTrue;
-
+import static org.junit.Assert.*;
 import java.io.IOException;
 import java.net.InetSocketAddress;
 import java.security.GeneralSecurityException;
@@ -36,6 +35,7 @@ import javax.net.ssl.TrustManagerFactory;
 import org.apache.mina.core.filterchain.DefaultIoFilterChainBuilder;
 import org.apache.mina.core.service.IoHandlerAdapter;
 import org.apache.mina.core.session.IoSession;
+import org.apache.mina.filter.FilterEvent;
 import org.apache.mina.filter.codec.ProtocolCodecFilter;
 import org.apache.mina.filter.codec.textline.TextLineCodecFactory;
 import org.apache.mina.transport.socket.nio.NioSocketAcceptor;
@@ -117,13 +117,13 @@ public class SslDIRMINA937Test {
         //sslFilter.setEnabledCipherSuites(getClientCipherSuites());
         filters.addLast("sslFilter", sslFilter);
         connector.setHandler(new IoHandlerAdapter() {
-            public void sessionCreated(IoSession session) throws Exception {
-                session.setAttribute(SslFilter.USE_NOTIFICATION, Boolean.TRUE);
+            @Override
+            public void messageReceived(IoSession session, Object message) throws Exception {
             }
 
             @Override
-            public void messageReceived(IoSession session, Object message) throws Exception {
-                if (message == SslFilter.SESSION_SECURED) {
+            public void event(IoSession session, FilterEvent event) throws Exception {
+                if (event == SslEvent.UNSECURED ) {
                     counter.countDown();
                 }
             }
